@@ -33,7 +33,7 @@ from google.cloud.secretmanager_v1.types import resources, service
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            "google-cloud-secretmanager",
+            "google-cloud-secret-manager",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
